@@ -35,7 +35,7 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group()
-@click.version_option("76.2.1", package_name="alacorder")
+@click.version_option("76.2.5", package_name="alacorder")
 def cli():
     """
     ALACORDER beta 76
@@ -366,8 +366,8 @@ def scrape(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update,
 
     if not ignore_complete:
         try:
-            is_comp = query.RETRIEVED_ON.map(lambda x: not pd.isnull(x))
-            query = query[is_comp]
+            incomplete = query.RETRIEVED_ON.map(lambda x: pd.isnull(x))
+            query = query[incomplete]
         except:
             pass
 
@@ -394,8 +394,12 @@ def scrape(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update,
 
     for i, n in enumerate(query.index):
         if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
-                login(driver, cID, uID, pwd, speed)
+                login(driver, cID, uID, pwd, speed, no_log)
         results = party_search(driver, name=query.NAME[n], party_type=query.PARTY_TYPE[n], ssn=query.SSN[n], dob=query.DOB[n], county=query.COUNTY[n], division=query.DIVISION[n], case_year=query.CASE_YEAR[n], no_records=query.NO_RECORDS[n], filed_before=query.FILED_BEFORE[n], filed_after=query.FILED_AFTER[n], speed=speed, no_log=no_log)
+        if len(results) == 0:
+            if not no_log:
+                click.echo(f"Skipped {query.NAME[n]} due to unknown issue...")
+            continue
         time.sleep(3)
         with click.progressbar(results, show_eta=False, label=f"{i+1}/{query.index.stop+1}: {query.NAME[n]}") as bar:
             for url in bar:
@@ -413,10 +417,13 @@ def scrape(listpath, path, cID, uID, pwd, qmax, qskip, speed, no_log, no_update,
 def login(driver, cID, username, pwd, speed, no_log=False):
 
     if not no_log:
-        click.echo("Logging in to Alacourt...")
+        click.echo("Connecting to Alacourt...")
 
     login_screen = driver.get("https://v2.alacourt.com/frmlogin.aspx")
 
+    if not no_log:
+        click.echo("Logging in...")
+
     driver.implicitly_wait(0.5/speed)
     
     cID_box = driver.find_element(by=By.NAME, 
@@ -443,34 +450,36 @@ def login(driver, cID, username, pwd, speed, no_log=False):
         pass
 
     driver.implicitly_wait(0.5/speed)
-    try:
-        driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")
-    except:
-        pass
+
+    driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")
+
+    if not no_log:
+        cal.echo_green("Successfully connected and logged into Alacourt!")
 
     driver.implicitly_wait(0.5/speed)
 
 def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", no_records="", filed_before="", filed_after="", speed=1.25, no_log=False):
 
-    time.sleep(2*speed)
+    driver.implicitly_wait(1/speed)
+
+    if "frmIndexSearchForm" not in driver.current_url:
+        driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")
+
     driver.implicitly_wait(5/speed)
-    driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")
+
 
     # connection error 
     try:
-        party_name_box = driver.find_element(by=By.ID,value="ContentPlaceHolder1_txtName")
+        party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
     except selenium.common.exceptions.NoSuchElementException:
         if not no_log:
             cal.echo_red("Connection error. Attempting reconnection...")
         driver.refresh()
         driver.implicitly_wait(10/speed)
         try:
-            party_name_box = driver.find_element(by=By.ID,value="ContentPlaceHolder1_txtName")
-        except selenium.common.exceptions.NoSuchElementException:
-            cal.echo_red("Connection error. Failed to reconnect! Waiting 1 minute to attempt reconnection...")
-            time.sleep(60)
-            driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")
-            party_name_box = driver.find_element(by=By.ID,value="ContentPlaceHolder1_txtName")
+            party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
+            if not no_log:
+                cal.echo_green("Successfully connected and logged into Alacourt!")
 
     # field search
 
@@ -483,15 +492,15 @@ def party_search(driver, name = "", party_type = "", ssn="", dob="", county="",
         date_of_birth_box.send_keys(dob)
         date_of_birth_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtDOB")
 
-    if party_type == "plaintiffs":
-        plaintiffs_select.click()
-        plaintiffs_select = driver.find_element(by=By.ID, value="ContentPlaceHolder1_rdlPartyType_0")
-    if party_type == "defendants":
-        defendents_select.click()
-        defendents_select = driver.find_element(by=By.ID, value="ContentPlaceHolder1_rdlPartyType_1")
-    if party_type == "ALL":
-        all_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$rdlPartyType")
-        all_select.click()
+    if party_type != "":
+        party_type_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$rdlPartyType")
+        if party_type == "plaintiffs":
+            plaintiffs_select.click()
+        if party_type == "defendants":
+            defendents_select.click()
+        if party_type == "all":
+            all_select.click()
+
     if county != "":
         county_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCounties")
         scounty = Select(county_select)
